@@ -1,5 +1,5 @@
 #!/usr/local/bin/ruby24
-# Copyright (c) 2015 Phusion Holding B.V.
+# Copyright (c) 2015-2017 Phusion Holding B.V.
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -23,6 +23,9 @@
 # This script uses GDB to attach to a process in order to dump the
 # backtraces of all its threads.
 
+STDOUT.sync = true
+STDERR.sync = true
+
 ruby_libdir    = ARGV.shift
 passenger_root = ARGV.shift
 require "#{ruby_libdir}/phusion_passenger"
